@@ -1,7 +1,3 @@
-( cd opt/kde/lib/kde3 ; rm -rf libvimpart.so )
-( cd opt/kde/lib/kde3 ; ln -sf libvimpart.so.0.0.0 libvimpart.so )
-( cd opt/kde/lib/kde3 ; rm -rf libvimpart.so.0 )
-( cd opt/kde/lib/kde3 ; ln -sf libvimpart.so.0.0.0 libvimpart.so.0 )
 ( cd opt/kde/lib ; rm -rf libxvim.so.0 )
 ( cd opt/kde/lib ; ln -sf libxvim.so.0.0.0 libxvim.so.0 )
 ( cd opt/kde/lib ; rm -rf libxvim.so )
